# Copyright 2018-2021 Xanadu Quantum Technologies Inc.

# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at

#     http://www.apache.org/licenses/LICENSE-2.0

# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""
This subpackage contains various quantum tapes, which track, queue,
validate, execute, and differentiate quantum circuits.
"""
from .tape import QuantumTape, get_active_tape
from .jacobian_tape import JacobianTape
from .cv_param_shift import CVParamShiftTape
from .qubit_param_shift import QubitParamShiftTape
from .reversible import ReversibleTape
from .operation_recorder import OperationRecorder
from .stop_recording import stop_recording
from .unwrap import Unwrap, UnwrapTape
